to_string

Function to_string 

pub fn to_string<V: Serialize>(
    input: &BTreeMap<KeyString, V>,
    fields_order: &[KeyString],
    key_value_delimiter: &str,
    field_delimiter: &str,
    flatten_boolean: bool,
) -> Result<String, EncodingError>
Encodes input to key value format with specified delimiters in field order where unspecified fields will follow after them. Flattens_boolean values to only a key if true.

Errors

Returns an EncodingError if the input contains non-String map keys.